"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class NtwNode {
    constructor(node) {
        this.id = node.id;
        this.fn = this.getNodeFunctions(node.fn);
        this.next = this.getAsArray(node.next).filter(n => n);
    }
    hasNext() {
        const next = this.next;
        return !!next && this.isArray(next) && next.length > 0;
    }
    getNextValue(currentValue, context) {
        return this.fn(currentValue, context);
    }
    getNodeFunctions(fns) {
        if (!this.isArrayOfFunctions(fns) && typeof fns !== 'function') {
            throw new Error(`${fns} provided to node ${this.id} is not a function`);
        }
        return fns;
    }
    isArrayOfFunctions(fns) {
        return this.isArray(fns) && fns.every(fn => typeof fn === 'function');
    }
    containsNotFunctionItem(fns) {
        return this.isArray(fns) || typeof fns !== 'function';
    }
    isArray(item) {
        return Array.isArray(item);
    }
    getAsArray(item) {
        return this.shouldBeAnArray(item) ? [item] : item;
    }
    shouldBeAnArray(item) {
        return !Array.isArray(item);
    }
}
exports.NtwNode = NtwNode;
//# sourceMappingURL=ntw-node.js.map