"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert = require('assert');
const ntw_node_1 = require("./ntw-node");
describe('Node', function () {
    describe('# next', function () {
        it('should contain only truthy values', function () {
            const values = [false, null, 'hello', undefined, 'world', 164, 0, NaN, '', ''];
            const node = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: values });
            assert.deepEqual(node.next.length, 3);
        });
    });
    describe('# hasNext()', function () {
        it('should return \'false\' when \'next\' is falsy', function () {
            const node1 = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: false });
            const node2 = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: null });
            const node3 = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: undefined });
            const node4 = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: 0 });
            const node5 = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: NaN });
            const node6 = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: '' });
            const node7 = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: '' });
            assert.deepEqual(node1.hasNext(), false);
            assert.deepEqual(node2.hasNext(), false);
            assert.deepEqual(node3.hasNext(), false);
            assert.deepEqual(node4.hasNext(), false);
            assert.deepEqual(node5.hasNext(), false);
            assert.deepEqual(node6.hasNext(), false);
            assert.deepEqual(node7.hasNext(), false);
        });
        it('should return \'false\' when \'next\' is an empty array', function () {
            const node = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: [] });
            assert.deepEqual(node.hasNext(), false);
        });
        it('should return \'false\' when \'next\' contains only falsy values', function () {
            const falsyValues = [false, null, undefined, 0, NaN, '', ''];
            const node = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: falsyValues });
            assert.deepEqual(node.hasNext(), false);
        });
        it('should return \'true\' when \'next\' is an array of at least one truthy value', function () {
            const node = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: [0, 'hello'] });
            assert.deepEqual(node.hasNext(), true);
        });
        it('should return \'true\' when \'next\' is a function expression', function () {
            const node = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: () => 4 });
            assert.deepEqual(node.hasNext(), true);
        });
        it('should return \'true\' when \'next\' is an array of function expressions', function () {
            const a = () => 4;
            const b = () => 5;
            const c = () => 6;
            const node = new ntw_node_1.NtwNode({ id: 0, fn: elem => ++elem, next: [a, b, c] });
            assert.deepEqual(node.hasNext(), true);
        });
    });
});
//# sourceMappingURL=ntw-node.spec.js.map