"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert = require("assert");
const ntw_processor_1 = require("./ntw-processor");
const Observable = require('rxjs/Observable').Observable;
require('rxjs/add/observable/of');
require('rxjs/add/operator/map');
const a = (elem, context) => {
    // Context must not be reassigned !
    // It would change the reference of the object
    context.value = 'Hello World !';
    return ++elem;
};
const b = (elem, context) => {
    return --elem;
};
const c = elem => elem * 3;
const d = elem => elem * 5;
const e = elem => elem / 2;
const f = elem => elem * 2;
const dispatchFn = elem => {
    if (elem > 20) {
        return [6, 7];
    }
    else {
        return 'end';
    }
};
const endFn = elem => 'Result : ' + elem;
const network = new ntw_processor_1.NtwProcessor([
    { id: 0, fn: a, next: ['chat', 'coq'] },
    { id: 'chat', fn: b, next: 'chien' },
    { id: 'coq', fn: c, next: ['vache', 5] },
    { id: 'chien', fn: d, next: 'mouton' },
    { id: 'mouton', fn: e, next: ['chevre', 'cheval'] },
    { id: 'chevre', fn: e },
    { id: 'cheval', fn: [a, b, c, d] },
    { id: 5, fn: f, next: dispatchFn },
    { id: 'end', fn: endFn },
    { id: 6, fn: b },
    { id: 7, fn: a }
]);
describe('Network', function () {
    describe('# init(2)', function () {
        let output;
        before(() => {
            output = network.init(2);
        });
        it('should return [2.5, 75, undefined, \'Result : 18\']', function () {
            const result = [];
            output.subscribe({
                next: res => {
                    result.push(res);
                },
                complete: () => assert.deepEqual(result, [2.5, 75, undefined, 'Result : 18'])
            });
        });
    });
    describe('# init(4)', function () {
        let output;
        before(() => {
            output = network.init(4);
        });
        it('should return [5, 150, undefined, 29, 31]', function () {
            const result = [];
            output.subscribe({
                next: res => {
                    result.push(res);
                },
                complete: () => assert.deepEqual(result, [5, 150, undefined, 29, 31])
            });
        });
    });
    describe('# init(12, \'mouton\')', function () {
        let output;
        before(() => {
            output = network.init(12, 'mouton');
        });
        it('should return [3, 90]', function () {
            const result = [];
            output.subscribe({
                next: res => {
                    result.push(res);
                },
                complete: () => assert.deepEqual(result, [3, 90])
            });
        });
    });
    describe('# context.value', function () {
        let output;
        before(() => {
            output = network.init(12, 'mouton');
        });
        it('should be set to \'Hello World !\'', function () {
            assert.deepEqual(network.context.value, 'Hello World !');
        });
    });
});
const linearNetwork = new ntw_processor_1.NtwProcessor([a, b, c, d, e, endFn]);
describe('Linear Network', function () {
    describe('# init(2)', function () {
        let output;
        before(() => {
            output = linearNetwork.init(2);
        });
        it('should return [\'Result : 15\']', function () {
            const result = [];
            output.subscribe({
                next: res => {
                    result.push(res);
                },
                complete: () => assert.deepEqual(result, ['Result : 15'])
            });
        });
    });
    describe('# context.value', function () {
        let output;
        before(() => {
            output = network.init(12, 'mouton');
        });
        it('should be set to \'Hello World !\'', function () {
            assert.deepEqual(network.context.value, 'Hello World !');
        });
    });
});
const aAsync = elem => Observable.of(elem);
const bAsync = elem => ++elem;
const cAsync = elem => 'End//' + elem;
const dAsync = elem => Observable.of(elem);
const eAsync = elem => elem instanceof Observable;
const networkAsync = new ntw_processor_1.NtwProcessor([
    { id: 0, fn: aAsync, next: [1, 2, 3] },
    { id: 1, fn: bAsync },
    { id: 2, fn: cAsync },
    { id: 3, fn: dAsync, next: 4 },
    { id: 4, fn: eAsync }
]);
describe('Network with async functions', function () {
    describe('# init(2)', function () {
        let output;
        before(() => {
            output = networkAsync.init(2);
        });
        it('should return [3, \'End//2\', false]', function () {
            const result = [];
            output.subscribe({
                next: res => {
                    result.push(res);
                },
                complete: () => assert.deepEqual(result, [3, 'End//2', false])
            });
        });
    });
});
//# sourceMappingURL=ntw-processor.spec.js.map